@@ -152,7 +152,7 @@ mod tests {
     fn test_parse_simple_expanded_tag() {
         let tags = ExpandedTags::parse(vec!["py3-none-any"]).unwrap();
 
-        insta::assert_debug_snapshot!(tags, @r"
+        insta::assert_debug_snapshot!(tags, @"
         ExpandedTags(
             [
                 Small {
@@ -179,7 +179,7 @@ mod tests {
         ])
         .unwrap();
 
-        insta::assert_debug_snapshot!(tags, @r"
+        insta::assert_debug_snapshot!(tags, @"
         ExpandedTags(
             [
                 Small {
@@ -211,11 +211,13 @@ mod tests {
                             ),
                         },
                         abi_tag: CPython {
-                            gil_disabled: false,
                             python_version: (
                                 3,
                                 9,
                             ),
+                            variant: CPythonAbiVariants(
+                                0,
+                            ),
                         },
                         platform_tag: Linux {
                             arch: X86_64,
@@ -250,11 +252,13 @@ mod tests {
                         ],
                         abi_tag: [
                             CPython {
-                                gil_disabled: false,
                                 python_version: (
                                     3,
                                     12,
                                 ),
+                                variant: CPythonAbiVariants(
+                                    0,
+                                ),
                             },
                         ],
                         platform_tag: [
@@ -383,7 +387,7 @@ mod tests {
         assert!(result.is_ok());
         let tag = result.unwrap();
 
-        insta::assert_debug_snapshot!(tag, @r"
+        insta::assert_debug_snapshot!(tag, @"
         Small {
             small: WheelTagSmall {
                 python_tag: Python {
@@ -423,18 +427,22 @@ mod tests {
                 ],
                 abi_tag: [
                     CPython {
-                        gil_disabled: false,
                         python_version: (
                             3,
                             9,
                         ),
+                        variant: CPythonAbiVariants(
+                            0,
+                        ),
                     },
                     CPython {
-                        gil_disabled: false,
                         python_version: (
                             3,
                             10,
                         ),
+                        variant: CPythonAbiVariants(
+                            0,
+                        ),
                     },
                 ],
                 platform_tag: [
