@@ -36,6 +36,7 @@ pub enum PreviewFeature {
     GcsEndpoint = 1 << 21,
     AdjustUlimit = 1 << 22,
     SpecialCondaEnvNames = 1 << 23,
+    RelocatableEnvsDefault = 1 << 24,
 }
 
 impl PreviewFeature {
@@ -66,6 +67,7 @@ impl PreviewFeature {
             Self::GcsEndpoint => "gcs-endpoint",
             Self::AdjustUlimit => "adjust-ulimit",
             Self::SpecialCondaEnvNames => "special-conda-env-names",
+            Self::RelocatableEnvsDefault => "relocatable-envs-default",
         }
     }
 }
@@ -109,6 +111,7 @@ impl FromStr for PreviewFeature {
             "metadata-json" => Self::MetadataJson,
             "adjust-ulimit" => Self::AdjustUlimit,
             "special-conda-env-names" => Self::SpecialCondaEnvNames,
+            "relocatable-envs-default" => Self::RelocatableEnvsDefault,
             _ => return Err(PreviewFeatureParseError),
         })
     }
@@ -151,10 +154,20 @@ impl Preview {
         Self::new(preview_features)
     }
 
-    /// Check if a single feature is enabled
+    /// Check if a single feature is enabled.
     pub fn is_enabled(&self, flag: PreviewFeature) -> bool {
         self.flags.contains(flag)
     }
+
+    /// Check if all preview feature rae enabled.
+    pub fn all_enabled(&self) -> bool {
+        self.flags.is_all()
+    }
+
+    /// Check if any preview feature is enabled.
+    pub fn any_enabled(&self) -> bool {
+        !self.flags.is_empty()
+    }
 }
 
 impl Display for Preview {
@@ -336,5 +349,9 @@ mod tests {
             PreviewFeature::SpecialCondaEnvNames.as_str(),
             "special-conda-env-names"
         );
+        assert_eq!(
+            PreviewFeature::RelocatableEnvsDefault.as_str(),
+            "relocatable-envs-default"
+        );
     }
 }
